@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 # shortcuts
 #  os and distros
@@ -106,7 +106,8 @@ sub mapping {
        [linuxdistrocodename => ['squeeze','wheezy'],
 	[package => ['libtool', 'libncurses5-dev']]],
        [package => ['libtool-bin', 'libncurses5-dev']]],
-      # XXX what about freebsd?
+      [like_fedora,
+       [package => ['libtool', 'ncurses-devel']]],
      ],
 
      [cpanmod => 'Alien::ProtoBuf',
@@ -399,6 +400,8 @@ sub mapping {
 
      [cpanmod => 'Cairo::GObject',
       [like_fedora,
+       [linuxdistroversion => qr{^6\.},
+	[package => []]],
        [package => 'cairo-gobject-devel']],
      ],
 
@@ -665,8 +668,12 @@ sub mapping {
       [os_freebsd,
        [package => 'mysql-connector-c | mysql57-client | mysql56-client | mysql55-client | mariadb101-client | mariadb100-client | mariadb55-client | percona56-client | percona55-client']],
       [like_debian,
+       [linuxdistrocodename => 'stretch',
+	[package => 'default-libmysqlclient-dev']],
        [package => 'libmysqlclient-dev']],
       [like_fedora,
+       [linuxdistroversion => qr{^6\.},
+	[package => 'mysql-devel']],
        [package => 'mariadb-devel']],
       [os_darwin,
        [package => 'mysql-connector-c | mysql']],
@@ -1005,6 +1012,8 @@ sub mapping {
 
      [cpanmod => 'Glib',
       [like_fedora,
+       [linuxdistroversion => qr{^6\.},
+	[package => []]],
        [package => 'gobject-introspection-devel']],
       [os_darwin,
        [package => 'glib']],
@@ -1060,11 +1069,14 @@ sub mapping {
        [package => 'libgnome2-dev']], # does not work, module does not look into /usr/include/libgnome-2.0/
      ],
 
-     [cpanmod => 'GnuPG::Interface',
+     [cpanmod => ['GnuPG', 'GnuPG::Interface'],
       [os_freebsd,
        [package => 'gnupg1'] #  XXX what about gnupg (version 2)?
       ],
-      # XXX what about debian?
+      [like_debian,
+       [package => 'gnupg']],
+      [like_fedora,
+       [package => 'gnupg2']],
      ],
 
      [cpanmod => 'Goo::Canvas',
@@ -1073,7 +1085,20 @@ sub mapping {
       [like_debian,
        [package => 'libgoocanvas-dev']],
       [like_fedora,
-       [package => 'goocanvas-devel']],
+       [package => 'goocanvas2']],
+     ],
+
+     [cpanmod => 'GooCanvas2',
+      [os_freebsd,
+       [package => 'goocanvas2']],
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy jessie)], # not available before xenial/stretch
+	[package => []]],
+       [package => 'gir1.2-goocanvas-2.0']],
+      [like_fedora,
+       [linuxdistroversion => qr{^6\.},
+	[package => []]],
+       [package => 'goocanvas2-devel']],
      ],
 
      [cpanmod => 'Google::ProtocolBuffers::Dynamic',
@@ -1189,6 +1214,8 @@ sub mapping {
       [like_debian,
        [package => 'libgtk-3-dev']],
       [like_fedora,
+       [linuxdistroversion => qr{^6\.},
+	[package => []]],
        [package => 'gtk3-devel']],
      ],
 
